@@ -19,6 +19,7 @@
 #
 """ Fedora Messaging Client API """
 
+import inspect
 import threading
 
 import fedmsg.core
@@ -62,10 +63,17 @@ def init(**kw):
 
 def API_function(doc=None):
     def api_function(func):
+        scrub = inspect.getargspec(func).args
 
         def _wrapper(*args, **kw):
             if not hasattr(__local, '__context'):
-                init(**kw)
+                config_overrides = kw.copy()
+
+                for arg in scrub:
+                    if arg in config_overrides:
+                        del config_overrides[arg]
+
+                init(**config_overrides)
                 assert(__local.__context)
 
             return func(*args, **kw)
