@@ -27,16 +27,12 @@ log = logging.getLogger(__name__)
 
 class RelayConsumer(FedmsgConsumer):
     config_key = 'fedmsg.consumers.relay.enabled'
+    topic = '*'
 
     def __init__(self, hub):
         self.hub = hub
         self.DBSession = None
 
-        # The consumer should pick up *all* messages.
-        self.topic = self.hub.config.get('topic_prefix', 'org.fedoraproject')
-        if not self.topic.endswith('*'):
-            self.topic += '*'
-
         super(RelayConsumer, self).__init__(hub)
 
         self.validate_signatures = False
