@@ -216,14 +216,14 @@ def validate(message, **config):
 
     cfg = copy.deepcopy(config)
     if 'gpg_home' not in cfg:
-        cfg['gpg_honme'] = os.path.expanduser('~/.gnupg/')
+        cfg['gpg_home'] = os.path.expanduser('~/.gnupg/')
 
     if 'ssldir' not in cfg:
         cfg['ssldir'] = '/etc/pki/fedmsg'
 
     if 'crypto' in message:
         if not message['crypto'] in _possible_backends:
-            log.warn("Message specified an unpossible crypto backend")
+            log.warn("Message specified an impossible crypto backend")
             return False
         try:
             backend = _possible_backends[message['crypto']]
