@@ -246,7 +246,8 @@ def _load_remote_cert(location, cache, cache_expiry, **config):
             with open(cache, 'w') as f:
                 f.write(response.content)
         except requests.exceptions.ConnectionError:
-            log.warn("Could not access %r" % location)
+            log.error("Could not access %r" % location)
+            raise
         except IOError as e:
             # If we couldn't write to the specified cache location, try a
             # similar place but inside our home directory instead.
